/*!
 * @certifaction/verification-vue-component 2.1.2
 *
 * @link https://certifaction.com
 * @source https://github.com/certifaction/verification/tree/master/packages/verification-vue-component
 * @copyright (c) 2019-2020 Certifaction AG
 * @license MIT
 */
import Vue from 'vue';
import VueScrollTo from 'vue-scrollto';
import { VERIFICATION_TYPES, Interface, VerifierInterface, CertifactionEthVerifier, PdfService, mapVerificationItemType, hashingService } from '@certifaction/verification-core';
import { mdiAlertCircle, mdiShield, mdiShieldCheck, mdiAlertOutline, mdiCheckDecagram, mdiChevronUp, mdiChevronDown, mdiInformationOutline } from '@mdi/js';
import Spinner from 'vue-simple-spinner';
import { VTooltip } from 'v-tooltip';

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) {
  try {
    var info = gen[key](arg);
    var value = info.value;
  } catch (error) {
    reject(error);
    return;
  }

  if (info.done) {
    resolve(value);
  } else {
    Promise.resolve(value).then(_next, _throw);
  }
}

function _asyncToGenerator(fn) {
  return function () {
    var self = this,
        args = arguments;
    return new Promise(function (resolve, reject) {
      var gen = fn.apply(self, args);

      function _next(value) {
        asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value);
      }

      function _throw(err) {
        asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err);
      }

      _next(undefined);
    });
  };
}

function _defineProperty(obj, key, value) {
  if (key in obj) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
  } else {
    obj[key] = value;
  }

  return obj;
}

function ownKeys(object, enumerableOnly) {
  var keys = Object.keys(object);

  if (Object.getOwnPropertySymbols) {
    var symbols = Object.getOwnPropertySymbols(object);
    if (enumerableOnly) symbols = symbols.filter(function (sym) {
      return Object.getOwnPropertyDescriptor(object, sym).enumerable;
    });
    keys.push.apply(keys, symbols);
  }

  return keys;
}

function _objectSpread2(target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = arguments[i] != null ? arguments[i] : {};

    if (i % 2) {
      ownKeys(Object(source), true).forEach(function (key) {
        _defineProperty(target, key, source[key]);
      });
    } else if (Object.getOwnPropertyDescriptors) {
      Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
    } else {
      ownKeys(Object(source)).forEach(function (key) {
        Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
      });
    }
  }

  return target;
}

function _slicedToArray(arr, i) {
  return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest();
}

function _arrayWithHoles(arr) {
  if (Array.isArray(arr)) return arr;
}

function _iterableToArrayLimit(arr, i) {
  if (typeof Symbol === "undefined" || !(Symbol.iterator in Object(arr))) return;
  var _arr = [];
  var _n = true;
  var _d = false;
  var _e = undefined;

  try {
    for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
      _arr.push(_s.value);

      if (i && _arr.length === i) break;
    }
  } catch (err) {
    _d = true;
    _e = err;
  } finally {
    try {
      if (!_n && _i["return"] != null) _i["return"]();
    } finally {
      if (_d) throw _e;
    }
  }

  return _arr;
}

function _unsupportedIterableToArray(o, minLen) {
  if (!o) return;
  if (typeof o === "string") return _arrayLikeToArray(o, minLen);
  var n = Object.prototype.toString.call(o).slice(8, -1);
  if (n === "Object" && o.constructor) n = o.constructor.name;
  if (n === "Map" || n === "Set") return Array.from(o);
  if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen);
}

function _arrayLikeToArray(arr, len) {
  if (len == null || len > arr.length) len = arr.length;

  for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i];

  return arr2;
}

function _nonIterableRest() {
  throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}

function _createForOfIteratorHelper(o, allowArrayLike) {
  var it;

  if (typeof Symbol === "undefined" || o[Symbol.iterator] == null) {
    if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") {
      if (it) o = it;
      var i = 0;

      var F = function () {};

      return {
        s: F,
        n: function () {
          if (i >= o.length) return {
            done: true
          };
          return {
            done: false,
            value: o[i++]
          };
        },
        e: function (e) {
          throw e;
        },
        f: F
      };
    }

    throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
  }

  var normalCompletion = true,
      didErr = false,
      err;
  return {
    s: function () {
      it = o[Symbol.iterator]();
    },
    n: function () {
      var step = it.next();
      normalCompletion = step.done;
      return step;
    },
    e: function (e) {
      didErr = true;
      err = e;
    },
    f: function () {
      try {
        if (!normalCompletion && it.return != null) it.return();
      } finally {
        if (didErr) throw err;
      }
    }
  };
}

var i18nWrapperMixin = {
  methods: {
    _$t: function _$t(key) {
      if (typeof this.$t === 'function') {
        for (var _len = arguments.length, values = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
          values[_key - 1] = arguments[_key];
        }

        return this.$t.apply(this, [key].concat(values));
      }

      return key;
    },
    _$tc: function _$tc(key, choice) {
      if (typeof this.$tc === 'function') {
        for (var _len2 = arguments.length, values = new Array(_len2 > 2 ? _len2 - 2 : 0), _key2 = 2; _key2 < _len2; _key2++) {
          values[_key2 - 2] = arguments[_key2];
        }

        return this.$tc.apply(this, [key, choice].concat(values));
      }

      return key;
    },
    _$te: function _$te(key, locale) {
      if (typeof this.$te === 'function') {
        return this.$te(key, locale);
      }

      return false;
    },
    _$d: function _$d(value) {
      if (typeof this.$d === 'function') {
        for (var _len3 = arguments.length, args = new Array(_len3 > 1 ? _len3 - 1 : 0), _key3 = 1; _key3 < _len3; _key3++) {
          args[_key3 - 1] = arguments[_key3];
        }

        return this.$d.apply(this, [value].concat(args));
      }

      return false;
    },
    _$n: function _$n(value) {
      if (typeof this.$n === 'function') {
        for (var _len4 = arguments.length, args = new Array(_len4 > 1 ? _len4 - 1 : 0), _key4 = 1; _key4 < _len4; _key4++) {
          args[_key4 - 1] = arguments[_key4];
        }

        return this.$n.apply(this, [value].concat(args));
      }

      return false;
    }
  }
};

var script = {
  name: 'MDIcon',
  props: {
    icon: {
      type: String,
      required: true
    }
  }
};

function normalizeComponent(template, style, script, scopeId, isFunctionalTemplate, moduleIdentifier, shadowMode, createInjector, createInjectorSSR, createInjectorShadow) {
  if (typeof shadowMode !== 'boolean') {
    createInjectorSSR = createInjector;
    createInjector = shadowMode;
    shadowMode = false;
  }

  var options = typeof script === 'function' ? script.options : script;

  if (template && template.render) {
    options.render = template.render;
    options.staticRenderFns = template.staticRenderFns;
    options._compiled = true;

    if (isFunctionalTemplate) {
      options.functional = true;
    }
  }

  if (scopeId) {
    options._scopeId = scopeId;
  }

  var hook;

  if (moduleIdentifier) {
    hook = function hook(context) {
      context = context || this.$vnode && this.$vnode.ssrContext || this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext;

      if (!context && typeof __VUE_SSR_CONTEXT__ !== 'undefined') {
        context = __VUE_SSR_CONTEXT__;
      }

      if (style) {
        style.call(this, createInjectorSSR(context));
      }

      if (context && context._registeredComponents) {
        context._registeredComponents.add(moduleIdentifier);
      }
    };

    options._ssrRegister = hook;
  } else if (style) {
    hook = shadowMode ? function (context) {
      style.call(this, createInjectorShadow(context, this.$root.$options.shadowRoot));
    } : function (context) {
      style.call(this, createInjector(context));
    };
  }

  if (hook) {
    if (options.functional) {
      var originalRender = options.render;

      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }

  return script;
}

/* script */
const __vue_script__ = script;

/* template */
var __vue_render__ = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('svg',{staticClass:"md-icon",attrs:{"viewBox":"0 0 24 24"}},[_c('path',{attrs:{"fill":"currentColor","d":_vm.icon}})])};
var __vue_staticRenderFns__ = [];

  /* style */
  const __vue_inject_styles__ = undefined;
  /* scoped */
  const __vue_scope_id__ = undefined;
  /* module identifier */
  const __vue_module_identifier__ = undefined;
  /* functional template */
  const __vue_is_functional_template__ = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__ = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__, staticRenderFns: __vue_staticRenderFns__ },
    __vue_inject_styles__,
    __vue_script__,
    __vue_scope_id__,
    __vue_is_functional_template__,
    __vue_module_identifier__,
    false,
    undefined,
    undefined,
    undefined
  );

var script$1 = {
  name: 'VerificationDemo',
  mixins: [i18nWrapperMixin],
  components: {
    MDIcon: __vue_component__
  },
  data: function data() {
    return {
      mdiAlertCircle: mdiAlertCircle,
      mdiShield: mdiShield,
      mdiShieldCheck: mdiShieldCheck
    };
  },
  methods: {
    randomLineClass: function randomLineClass() {
      return Math.random() > 0.5 ? 'line-long' : 'line-short';
    }
  }
};

/* script */
const __vue_script__$1 = script$1;

/* template */
var __vue_render__$1 = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',{staticClass:"verification-demo"},[_c('div',{staticClass:"sample-docs"},[_c('h3',[_vm._v(_vm._s(_vm._$t('verification.demo.title')))]),_vm._v(" "),_c('span',{staticClass:"click-to-verify"},[_vm._v(_vm._s(_vm._$t('verification.demo.clickToVerify')))]),_vm._v(" "),_c('div',{staticClass:"docs"},[_c('div',{staticClass:"paperbox"},[_c('div',{directives:[{name:"tooltip",rawName:"v-tooltip.top",value:(_vm._$t('verification.demo.notFound.tooltip')),expression:"_$t('verification.demo.notFound.tooltip')",modifiers:{"top":true}}],staticClass:"paper paper-not-found",attrs:{"draggable":""},on:{"click":function($event){return _vm.$emit('verifyDemo', 'notFound')},"dragstart":function($event){return _vm.$emit('draggingDemoDoc', 'notFound')},"dragend":function($event){return _vm.$emit('draggingDemoDoc')}}},[_c('MDIcon',{attrs:{"icon":_vm.mdiAlertCircle}}),_vm._v(" "),_c('div',{staticClass:"lines"},_vm._l((4),function(n){return _c('div',{key:n,class:_vm.randomLineClass()})}),0)],1),_vm._v(" "),_c('div',{directives:[{name:"tooltip",rawName:"v-tooltip.top",value:(_vm._$t('verification.demo.technicalProblem.tooltip')),expression:"_$t('verification.demo.technicalProblem.tooltip')",modifiers:{"top":true}}],staticClass:"paper paper-technical-problem",attrs:{"draggable":""},on:{"click":function($event){return _vm.$emit('verifyDemo', 'technicalProblem')},"dragstart":function($event){return _vm.$emit('draggingDemoDoc', 'technicalProblem')},"dragend":function($event){return _vm.$emit('draggingDemoDoc')}}},[_c('MDIcon',{attrs:{"icon":_vm.mdiAlertCircle}}),_vm._v(" "),_c('div',{staticClass:"lines"},_vm._l((4),function(n){return _c('div',{key:n,class:_vm.randomLineClass()})}),0)],1),_vm._v(" "),_c('div',{directives:[{name:"tooltip",rawName:"v-tooltip.top",value:(_vm._$t('verification.demo.verifiedProcessing.tooltip')),expression:"_$t('verification.demo.verifiedProcessing.tooltip')",modifiers:{"top":true}}],staticClass:"paper paper-verified-processing",attrs:{"draggable":""},on:{"click":function($event){return _vm.$emit('verifyDemo', 'verifiedProcessing')},"dragstart":function($event){return _vm.$emit('draggingDemoDoc', 'verifiedProcessing')},"dragend":function($event){return _vm.$emit('draggingDemoDoc')}}},[_c('MDIcon',{attrs:{"icon":_vm.mdiShield}}),_vm._v(" "),_c('div',{staticClass:"lines"},_vm._l((4),function(n){return _c('div',{key:n,class:_vm.randomLineClass()})}),0)],1),_vm._v(" "),_c('div',{directives:[{name:"tooltip",rawName:"v-tooltip.top",value:(_vm._$t('verification.demo.verified.tooltip')),expression:"_$t('verification.demo.verified.tooltip')",modifiers:{"top":true}}],staticClass:"paper paper-verified",attrs:{"draggable":""},on:{"click":function($event){return _vm.$emit('verifyDemo', 'verified')},"dragstart":function($event){return _vm.$emit('draggingDemoDoc', 'verified')},"dragend":function($event){return _vm.$emit('draggingDemoDoc')}}},[_c('MDIcon',{attrs:{"icon":_vm.mdiShieldCheck}}),_vm._v(" "),_c('div',{staticClass:"lines"},_vm._l((4),function(n){return _c('div',{key:n,class:_vm.randomLineClass()})}),0)],1),_vm._v(" "),_c('div',{directives:[{name:"tooltip",rawName:"v-tooltip.top",value:(_vm._$t('verification.demo.verifiedSelfDeclared.tooltip')),expression:"_$t('verification.demo.verifiedSelfDeclared.tooltip')",modifiers:{"top":true}}],staticClass:"paper paper-verified-self-declared",attrs:{"draggable":""},on:{"click":function($event){return _vm.$emit('verifyDemo', 'verifiedSelfDeclared')},"dragstart":function($event){return _vm.$emit('draggingDemoDoc', 'verifiedSelfDeclared')},"dragend":function($event){return _vm.$emit('draggingDemoDoc')}}},[_c('MDIcon',{attrs:{"icon":_vm.mdiShieldCheck}}),_vm._v(" "),_c('div',{staticClass:"lines"},_vm._l((4),function(n){return _c('div',{key:n,class:_vm.randomLineClass()})}),0)],1),_vm._v(" "),_c('div',{directives:[{name:"tooltip",rawName:"v-tooltip.top",value:(_vm._$t('verification.demo.revokedVerified.tooltip')),expression:"_$t('verification.demo.revokedVerified.tooltip')",modifiers:{"top":true}}],staticClass:"paper paper-revoked-verified",attrs:{"draggable":""},on:{"click":function($event){return _vm.$emit('verifyDemo', 'revokedVerified')},"dragstart":function($event){return _vm.$emit('draggingDemoDoc', 'revokedVerified')},"dragend":function($event){return _vm.$emit('draggingDemoDoc')}}},[_c('MDIcon',{attrs:{"icon":_vm.mdiShieldCheck}}),_vm._v(" "),_c('div',{staticClass:"lines"},_vm._l((4),function(n){return _c('div',{key:n,class:_vm.randomLineClass()})}),0)],1)])])])])};
var __vue_staticRenderFns__$1 = [];

  /* style */
  const __vue_inject_styles__$1 = undefined;
  /* scoped */
  const __vue_scope_id__$1 = undefined;
  /* module identifier */
  const __vue_module_identifier__$1 = undefined;
  /* functional template */
  const __vue_is_functional_template__$1 = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$1 = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$1, staticRenderFns: __vue_staticRenderFns__$1 },
    __vue_inject_styles__$1,
    __vue_script__$1,
    __vue_scope_id__$1,
    __vue_is_functional_template__$1,
    __vue_module_identifier__$1,
    false,
    undefined,
    undefined,
    undefined
  );

var script$2 = {
  name: 'VerificationDropBox',
  mixins: [i18nWrapperMixin],
  data: function data() {
    return {
      draggingOver: false
    };
  },
  methods: {
    handleDrop: function handleDrop() {
      this.draggingOver = false;
      this.$emit('drop');
    },
    filesDropped: function filesDropped(target, files) {
      this.$emit('filesDropped', files);
    }
  }
};

/* script */
const __vue_script__$2 = script$2;

/* template */
var __vue_render__$2 = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',{staticClass:"verification-dropbox",class:{dragover:_vm.draggingOver},on:{"dragover":function($event){$event.preventDefault();_vm.draggingOver = true;},"dragleave":function($event){_vm.draggingOver = false;},"drop":_vm.handleDrop}},[_c('div',{staticClass:"dropbox"},[_c('div',{staticClass:"labels"},[_c('div',{staticClass:"label title"},[_vm._v(_vm._s(_vm._$t('verification.dropbox.title')))]),_vm._v(" "),_c('div',{staticClass:"label subtitle"},[_vm._v(_vm._s(_vm._$t('verification.dropbox.subtitle')))])]),_vm._v(" "),_c('input',{staticClass:"input-file",attrs:{"type":"file","multiple":"","name":"uploadField","accept":"application/pdf"},on:{"change":function($event){return _vm.filesDropped($event.target.name, $event.target.files)}}})])])};
var __vue_staticRenderFns__$2 = [];

  /* style */
  const __vue_inject_styles__$2 = undefined;
  /* scoped */
  const __vue_scope_id__$2 = undefined;
  /* module identifier */
  const __vue_module_identifier__$2 = undefined;
  /* functional template */
  const __vue_is_functional_template__$2 = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$2 = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$2, staticRenderFns: __vue_staticRenderFns__$2 },
    __vue_inject_styles__$2,
    __vue_script__$2,
    __vue_scope_id__$2,
    __vue_is_functional_template__$2,
    __vue_module_identifier__$2,
    false,
    undefined,
    undefined,
    undefined
  );

var script$3 = {
  name: 'ShadowItem'
};

/* script */
const __vue_script__$3 = script$3;

/* template */
var __vue_render__$3 = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _vm._m(0)};
var __vue_staticRenderFns__$3 = [function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',{staticClass:"verification-item verification-shadow-item"},[_c('div',{staticClass:"lines"},[_c('div',{staticClass:"line short"}),_vm._v(" "),_c('div',{staticClass:"divider"}),_vm._v(" "),_c('div',{staticClass:"line medium"}),_vm._v(" "),_c('div',{staticClass:"line long"}),_vm._v(" "),_c('div',{staticClass:"line long"}),_vm._v(" "),_c('div',{staticClass:"line short"}),_vm._v(" "),_c('div',{staticClass:"line medium"})])])}];

  /* style */
  const __vue_inject_styles__$3 = undefined;
  /* scoped */
  const __vue_scope_id__$3 = undefined;
  /* module identifier */
  const __vue_module_identifier__$3 = undefined;
  /* functional template */
  const __vue_is_functional_template__$3 = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$3 = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$3, staticRenderFns: __vue_staticRenderFns__$3 },
    __vue_inject_styles__$3,
    __vue_script__$3,
    __vue_scope_id__$3,
    __vue_is_functional_template__$3,
    __vue_module_identifier__$3,
    false,
    undefined,
    undefined,
    undefined
  );

VTooltip.options.defaultContainer = '.certifaction-verification';
Vue.directive('tooltip', VTooltip);
var script$4 = {
  name: 'LayoutVerificationItem',
  mixins: [i18nWrapperMixin],
  props: ['verificationItem'],
  components: {
    Spinner: Spinner,
    MDIcon: __vue_component__
  },
  data: function data() {
    return {
      mdiAlertOutline: mdiAlertOutline,
      mdiCheckDecagram: mdiCheckDecagram,
      mdiChevronUp: mdiChevronUp,
      mdiChevronDown: mdiChevronDown,
      mdiInformationOutline: mdiInformationOutline,
      VERIFICATION_TYPES: VERIFICATION_TYPES,
      showAdvancedInfo: false
    };
  },
  computed: {
    net: function net() {
      if (this.$parent.$parent.$parent.certifactionEthVerifier.certifactionEthClient.eth.currentProvider.host.indexOf('ropsten') >= 0) {
        return 'ropsten.etherscan.io';
      } else {
        return 'etherscan.io';
      }
    },
    isLoaded: function isLoaded() {
      return this.verificationItem.loaded === true;
    }
  },
  methods: {
    dateFormat: function dateFormat(timestamp) {
      var date = new Date(timestamp * 1000);
      var options = {
        year: 'numeric',
        month: 'long',
        day: '2-digit',
        hour: '2-digit',
        minute: '2-digit',
        second: '2-digit'
      };
      return date.toLocaleString(this.$i18n.locale ? this.$i18n.locale : 'en', options);
    }
  }
};

/* script */
const __vue_script__$4 = script$4;

/* template */
var __vue_render__$4 = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',{staticClass:"verification-item",class:{expanded: _vm.showAdvancedInfo}},[_c('div',{staticClass:"item-header",on:{"click":function($event){_vm.showAdvancedInfo = false;}}},[(_vm.isLoaded)?_c('div',{staticClass:"icon"},[_vm._t("icon")],2):_vm._e(),_vm._v(" "),_c('div',{staticClass:"title"},[_c('div',{staticClass:"filename"},[_vm._v(_vm._s(_vm.verificationItem.name))])])]),_vm._v(" "),_c('div',{staticClass:"item-body"},[_c('div',{staticClass:"status"},[(_vm.isLoaded)?_vm._t("title"):_vm._e()],2),_vm._v(" "),_c('transition',{attrs:{"name":"expand","mode":"out-in"}},[(!_vm.isLoaded)?_c('div',{key:"spinner",staticClass:"loading-spinner"},[_c('Spinner')],1):_c('div',{key:"info",staticClass:"verification-info"},[(_vm.verificationItem.issuerName)?_c('div',{staticClass:"verification-entry issuer"},[_c('span',{staticClass:"stacked-title"},[_vm._v(_vm._s(_vm._$t('verification.result.meta.issuer')))]),_vm._v(" "),_c('span',{staticClass:"name"},[_c('span',[_vm._v(_vm._s(_vm.verificationItem.issuerName))]),_vm._v(" "),(_vm.verificationItem.issuerVerified)?_c('MDIcon',{staticClass:"verified",attrs:{"icon":_vm.mdiCheckDecagram}}):_vm._e()],1)]):_vm._e(),_vm._v(" "),(_vm.verificationItem.issuerVerifiedBy)?_c('div',{staticClass:"verification-entry verifier"},[_c('div',{staticClass:"verifier-name"},[_c('span',{staticClass:"stacked-title"},[_vm._v(_vm._s(_vm._$t('verification.result.meta.issuerVerifiedBy')))]),_vm._v(" "),_c('span',{staticClass:"name"},[_c('span',[_vm._v(_vm._s(_vm.verificationItem.issuerVerifiedBy))]),_vm._v(" "),_c('MDIcon',{directives:[{name:"tooltip",rawName:"v-tooltip.right",value:(_vm._$t('verification.result.meta.issuerVerifiedByInformation')),expression:"_$t('verification.result.meta.issuerVerifiedByInformation')",modifiers:{"right":true}}],attrs:{"icon":_vm.mdiInformationOutline}})],1)]),_vm._v(" "),_c('div',{staticClass:"verifier-image"},[(_vm.verificationItem.issuerVerifiedImg)?_c('img',{attrs:{"src":_vm.verificationItem.issuerVerifiedImg,"alt":""}}):_vm._e()])]):_vm._e(),_vm._v(" "),(_vm.verificationItem.issuerVerified && !_vm.verificationItem.issuerVerifiedBy)?_c('div',{staticClass:"verification-entry verifier"},[_c('div',{staticClass:"verifier-name"},[_c('span',{staticClass:"stacked-title"},[_vm._v(_vm._s(_vm._$t('verification.result.meta.issuerVerifiedBy')))]),_vm._v(" "),_c('span',{staticClass:"name"},[_c('span',[_vm._v("Certifaction AG")]),_vm._v(" "),_c('MDIcon',{directives:[{name:"tooltip",rawName:"v-tooltip.right",value:(_vm._$t('verification.result.meta.issuerVerifiedByInformation')),expression:"_$t('verification.result.meta.issuerVerifiedByInformation')",modifiers:{"right":true}}],attrs:{"icon":_vm.mdiInformationOutline}})],1)])]):_vm._e(),_vm._v(" "),(_vm.verificationItem.registrationBlock)?_c('div',{staticClass:"verification-entry registration-date"},[_c('span',{staticClass:"stacked-title"},[_vm._v(_vm._s(_vm._$t('verification.result.meta.registrationDate')))]),_vm._v(" "),_c('span',{staticClass:"date"},[_vm._v(_vm._s(_vm.dateFormat(_vm.verificationItem.registrationBlock.timestamp)))])]):_vm._e(),_vm._v(" "),(_vm.verificationItem.revocationBlock)?_c('div',{staticClass:"verification-entry revocation-date"},[_c('span',{staticClass:"stacked-title"},[_vm._v(_vm._s(_vm._$t('verification.result.meta.revocationDate')))]),_vm._v(" "),_c('span',{staticClass:"date"},[_vm._v(_vm._s(_vm.dateFormat(_vm.verificationItem.revocationBlock.timestamp)))])]):_vm._e()])]),_vm._v(" "),(_vm.isLoaded)?_c('div',{staticClass:"description"},[_vm._t("description"),_vm._v(" "),(_vm.verificationItem.offchainError &&
                (_vm.verificationItem.type === _vm.VERIFICATION_TYPES.V_VERIFIED || _vm.verificationItem.type === _vm.VERIFICATION_TYPES.V_NOT_FOUND))?_c('div',{staticClass:"offchain-error"},[_c('MDIcon',{attrs:{"icon":_vm.mdiAlertOutline}}),_vm._v(" "),_c('span',{staticClass:"offchain-error-title"},[_vm._v(_vm._s(_vm._$t('verification.result.technicalProblem.status')))]),_vm._v(" "),_c('div',{staticClass:"offchain-error-description",domProps:{"innerHTML":_vm._s(_vm._$t('verification.result.technicalProblem.offchainMessage'))}})],1):_vm._e()],2):_vm._e()],1),_vm._v(" "),(_vm.verificationItem.issuerAddress && _vm.isLoaded && !_vm.verificationItem.error)?_c('div',{staticClass:"item-footer"},[(_vm.showAdvancedInfo === false)?_c('button',{staticClass:"btn-link advanced-toggler",attrs:{"type":"button"},on:{"click":function($event){$event.preventDefault();_vm.showAdvancedInfo = true;}}},[_c('MDIcon',{staticClass:"toggler",attrs:{"icon":_vm.mdiChevronUp}}),_vm._v(" "),_c('span',[_vm._v(_vm._s(_vm._$t('verification.result.expertInfo.show')))])],1):_c('div',{key:"opened"},[_c('button',{key:"closed",staticClass:"btn-link advanced-toggler",attrs:{"type":"button"},on:{"click":function($event){$event.preventDefault();_vm.showAdvancedInfo = !_vm.showAdvancedInfo;}}},[_c('span',[_vm._v(_vm._s(_vm._$t('verification.result.expertInfo.hide')))]),_vm._v(" "),_c('MDIcon',{staticClass:"toggler",attrs:{"icon":_vm.mdiChevronDown}})],1),_vm._v(" "),_vm._t("advanced",[_c('div',{staticClass:"advanced-info"},[(_vm.verificationItem.issuerAddress)?_c('div',{staticClass:"verification-entry issuer-address"},[_c('span',{staticClass:"stacked-title"},[_vm._v(_vm._s(_vm._$t('verification.result.meta.issuerAddress')))]),_vm._v(" "),_c('div',{staticClass:"hash"},[_c('div',{staticClass:"content"},[_vm._v(_vm._s(_vm.verificationItem.issuerAddress))])])]):_vm._e(),_vm._v(" "),(_vm.verificationItem.hash)?_c('div',{staticClass:"verification-entry fingerprint"},[_c('span',{staticClass:"stacked-title"},[_vm._v(_vm._s(_vm._$t('verification.result.meta.fingerprint')))]),_vm._v(" "),_c('div',{staticClass:"hash"},[_c('div',{staticClass:"content"},[_vm._v(_vm._s(_vm.verificationItem.hash))])])]):_vm._e(),_vm._v(" "),(_vm.verificationItem.registrationEvent)?_c('div',{staticClass:"verification-entry registration-hash"},[_c('span',{staticClass:"stacked-title"},[_vm._v(_vm._s(_vm._$t('verification.result.meta.registrationTransaction')))]),_vm._v(" "),_c('div',{staticClass:"hash"},[_c('div',{staticClass:"content"},[_c('a',{attrs:{"href":("https://" + _vm.net + "/tx/" + (_vm.verificationItem.registrationEvent.transactionHash)),"target":"_blank"}},[_vm._v(_vm._s(_vm.verificationItem.registrationEvent.transactionHash))])])])]):(!_vm.verificationItem.onBlockchain)?_c('div',{staticClass:"verification-entry registration-status"},[_c('span',{staticClass:"stacked-title"},[_vm._v(_vm._s(_vm._$t('verification.result.meta.registrationTransaction')))]),_vm._v(" "),_c('div',{staticClass:"status",domProps:{"innerHTML":_vm._s(_vm._$t('verification.result.processing.status'))}})]):_vm._e(),_vm._v(" "),(_vm.verificationItem.revocationEvent)?_c('div',{staticClass:"verification-entry revocation-hash"},[_c('span',{staticClass:"stacked-title"},[_vm._v(_vm._s(_vm._$t('verification.result.meta.revocationTransaction')))]),_vm._v(" "),_c('div',{staticClass:"hash"},[_c('div',{staticClass:"content"},[_c('a',{attrs:{"href":("https://" + _vm.net + "/tx/" + (_vm.verificationItem.revocationEvent.transactionHash)),"target":"_blank"}},[_vm._v(_vm._s(_vm.verificationItem.revocationEvent.transactionHash))])])])]):_vm._e()])])],2)]):_vm._e()])};
var __vue_staticRenderFns__$4 = [];

  /* style */
  const __vue_inject_styles__$4 = undefined;
  /* scoped */
  const __vue_scope_id__$4 = undefined;
  /* module identifier */
  const __vue_module_identifier__$4 = undefined;
  /* functional template */
  const __vue_is_functional_template__$4 = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$4 = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$4, staticRenderFns: __vue_staticRenderFns__$4 },
    __vue_inject_styles__$4,
    __vue_script__$4,
    __vue_scope_id__$4,
    __vue_is_functional_template__$4,
    __vue_module_identifier__$4,
    false,
    undefined,
    undefined,
    undefined
  );

var script$5 = {
  name: 'VerificationItemNotFound',
  mixins: [i18nWrapperMixin],
  props: ['verificationItem'],
  components: {
    LayoutVerificationItem: __vue_component__$4,
    MDIcon: __vue_component__
  },
  data: function data() {
    return {
      mdiAlertCircle: mdiAlertCircle
    };
  }
};

/* script */
const __vue_script__$5 = script$5;

/* template */
var __vue_render__$5 = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('LayoutVerificationItem',{attrs:{"verificationItem":_vm.verificationItem},scopedSlots:_vm._u([{key:"icon",fn:function(){return [_c('MDIcon',{staticClass:"icon-not-found",attrs:{"icon":_vm.mdiAlertCircle}})]},proxy:true},{key:"title",fn:function(){return [_vm._v(_vm._s(_vm._$t('verification.result.notFound.status')))]},proxy:true},{key:"description",fn:function(){return [_c('div',{domProps:{"innerHTML":_vm._s(_vm._$t('verification.result.notFound.message'))}})]},proxy:true}])})};
var __vue_staticRenderFns__$5 = [];

  /* style */
  const __vue_inject_styles__$5 = undefined;
  /* scoped */
  const __vue_scope_id__$5 = undefined;
  /* module identifier */
  const __vue_module_identifier__$5 = undefined;
  /* functional template */
  const __vue_is_functional_template__$5 = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$5 = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$5, staticRenderFns: __vue_staticRenderFns__$5 },
    __vue_inject_styles__$5,
    __vue_script__$5,
    __vue_scope_id__$5,
    __vue_is_functional_template__$5,
    __vue_module_identifier__$5,
    false,
    undefined,
    undefined,
    undefined
  );

var script$6 = {
  name: 'VerificationItemRevoked',
  mixins: [i18nWrapperMixin],
  props: ['verificationItem'],
  components: {
    MDIcon: __vue_component__,
    LayoutVerificationItem: __vue_component__$4
  },
  data: function data() {
    return {
      mdiShieldCheck: mdiShieldCheck
    };
  }
};

/* script */
const __vue_script__$6 = script$6;

/* template */
var __vue_render__$6 = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('LayoutVerificationItem',{attrs:{"verificationItem":_vm.verificationItem},scopedSlots:_vm._u([{key:"icon",fn:function(){return [_c('MDIcon',{staticClass:"icon-revoked",attrs:{"icon":_vm.mdiShieldCheck}})]},proxy:true},{key:"title",fn:function(){return [_vm._v(_vm._s(_vm._$t('verification.result.revoked.status')))]},proxy:true},{key:"description",fn:function(){return [_c('div',{domProps:{"innerHTML":_vm._s(_vm._$t('verification.result.revoked.message'))}})]},proxy:true}])})};
var __vue_staticRenderFns__$6 = [];

  /* style */
  const __vue_inject_styles__$6 = undefined;
  /* scoped */
  const __vue_scope_id__$6 = undefined;
  /* module identifier */
  const __vue_module_identifier__$6 = undefined;
  /* functional template */
  const __vue_is_functional_template__$6 = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$6 = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$6, staticRenderFns: __vue_staticRenderFns__$6 },
    __vue_inject_styles__$6,
    __vue_script__$6,
    __vue_scope_id__$6,
    __vue_is_functional_template__$6,
    __vue_module_identifier__$6,
    false,
    undefined,
    undefined,
    undefined
  );

var script$7 = {
  name: 'VerificationItemRevokedUnverified',
  mixins: [i18nWrapperMixin],
  props: ['verificationItem'],
  components: {
    MDIcon: __vue_component__,
    LayoutVerificationItem: __vue_component__$4
  },
  data: function data() {
    return {
      mdiShieldCheck: mdiShieldCheck
    };
  }
};

/* script */
const __vue_script__$7 = script$7;

/* template */
var __vue_render__$7 = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('LayoutVerificationItem',{attrs:{"verificationItem":_vm.verificationItem},scopedSlots:_vm._u([{key:"icon",fn:function(){return [_c('MDIcon',{staticClass:"icon-revoked",attrs:{"icon":_vm.mdiShieldCheck}})]},proxy:true},{key:"title",fn:function(){return [_vm._v(_vm._s(_vm._$t('verification.result.revokedUnverified.status')))]},proxy:true},{key:"description",fn:function(){return [_c('div',{domProps:{"innerHTML":_vm._s(_vm._$t('verification.result.revokedUnverified.message'))}})]},proxy:true}])})};
var __vue_staticRenderFns__$7 = [];

  /* style */
  const __vue_inject_styles__$7 = undefined;
  /* scoped */
  const __vue_scope_id__$7 = undefined;
  /* module identifier */
  const __vue_module_identifier__$7 = undefined;
  /* functional template */
  const __vue_is_functional_template__$7 = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$7 = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$7, staticRenderFns: __vue_staticRenderFns__$7 },
    __vue_inject_styles__$7,
    __vue_script__$7,
    __vue_scope_id__$7,
    __vue_is_functional_template__$7,
    __vue_module_identifier__$7,
    false,
    undefined,
    undefined,
    undefined
  );

var script$8 = {
  name: 'VerificationItemUnverifiedIssuer',
  mixins: [i18nWrapperMixin],
  props: ['verificationItem'],
  components: {
    MDIcon: __vue_component__,
    LayoutVerificationItem: __vue_component__$4
  },
  data: function data() {
    return {
      mdiShieldCheck: mdiShieldCheck
    };
  }
};

/* script */
const __vue_script__$8 = script$8;

/* template */
var __vue_render__$8 = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('LayoutVerificationItem',{attrs:{"verificationItem":_vm.verificationItem},scopedSlots:_vm._u([{key:"icon",fn:function(){return [_c('MDIcon',{staticClass:"icon-unverified",attrs:{"icon":_vm.mdiShieldCheck}})]},proxy:true},{key:"title",fn:function(){return [_vm._v(_vm._s(_vm._$t('verification.result.selfDeclared.status')))]},proxy:true},{key:"description",fn:function(){return [_c('div',{domProps:{"innerHTML":_vm._s(_vm._$t('verification.result.selfDeclared.message'))}})]},proxy:true}])})};
var __vue_staticRenderFns__$8 = [];

  /* style */
  const __vue_inject_styles__$8 = undefined;
  /* scoped */
  const __vue_scope_id__$8 = undefined;
  /* module identifier */
  const __vue_module_identifier__$8 = undefined;
  /* functional template */
  const __vue_is_functional_template__$8 = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$8 = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$8, staticRenderFns: __vue_staticRenderFns__$8 },
    __vue_inject_styles__$8,
    __vue_script__$8,
    __vue_scope_id__$8,
    __vue_is_functional_template__$8,
    __vue_module_identifier__$8,
    false,
    undefined,
    undefined,
    undefined
  );

var script$9 = {
  name: 'VerificationItemVerified',
  mixins: [i18nWrapperMixin],
  props: ['verificationItem'],
  components: {
    MDIcon: __vue_component__,
    LayoutVerificationItem: __vue_component__$4
  },
  data: function data() {
    return {
      mdiShieldCheck: mdiShieldCheck
    };
  }
};

/* script */
const __vue_script__$9 = script$9;

/* template */
var __vue_render__$9 = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('LayoutVerificationItem',{attrs:{"verificationItem":_vm.verificationItem},scopedSlots:_vm._u([{key:"icon",fn:function(){return [_c('MDIcon',{staticClass:"icon-verified",attrs:{"icon":_vm.mdiShieldCheck}})]},proxy:true},{key:"title",fn:function(){return [_vm._v(_vm._s(_vm._$t('verification.result.verified.status')))]},proxy:true},{key:"description",fn:function(){return [_c('div',{domProps:{"innerHTML":_vm._s(_vm._$t('verification.result.verified.message'))}})]},proxy:true}])})};
var __vue_staticRenderFns__$9 = [];

  /* style */
  const __vue_inject_styles__$9 = undefined;
  /* scoped */
  const __vue_scope_id__$9 = undefined;
  /* module identifier */
  const __vue_module_identifier__$9 = undefined;
  /* functional template */
  const __vue_is_functional_template__$9 = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$9 = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$9, staticRenderFns: __vue_staticRenderFns__$9 },
    __vue_inject_styles__$9,
    __vue_script__$9,
    __vue_scope_id__$9,
    __vue_is_functional_template__$9,
    __vue_module_identifier__$9,
    false,
    undefined,
    undefined,
    undefined
  );

var script$a = {
  name: 'VerificationItemNotFound',
  mixins: [i18nWrapperMixin],
  props: ['verificationItem'],
  components: {
    LayoutVerificationItem: __vue_component__$4,
    MDIcon: __vue_component__
  },
  data: function data() {
    return {
      mdiAlertCircle: mdiAlertCircle
    };
  }
};

/* script */
const __vue_script__$a = script$a;

/* template */
var __vue_render__$a = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('LayoutVerificationItem',{attrs:{"verificationItem":_vm.verificationItem},scopedSlots:_vm._u([{key:"icon",fn:function(){return [_c('MDIcon',{staticClass:"icon-not-found",attrs:{"icon":_vm.mdiAlertCircle}})]},proxy:true},{key:"title",fn:function(){return [_vm._v(_vm._s(_vm._$t('verification.result.technicalProblem.status')))]},proxy:true},(!_vm.verificationItem.offchainError)?{key:"description",fn:function(){return [_c('div',{domProps:{"innerHTML":_vm._s(_vm._$t('verification.result.technicalProblem.message'))}})]},proxy:true}:{key:"description",fn:function(){return [_c('div',{domProps:{"innerHTML":_vm._s(_vm._$t('verification.result.technicalProblem.offchainMessage'))}})]},proxy:true}],null,true)})};
var __vue_staticRenderFns__$a = [];

  /* style */
  const __vue_inject_styles__$a = undefined;
  /* scoped */
  const __vue_scope_id__$a = undefined;
  /* module identifier */
  const __vue_module_identifier__$a = undefined;
  /* functional template */
  const __vue_is_functional_template__$a = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$a = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$a, staticRenderFns: __vue_staticRenderFns__$a },
    __vue_inject_styles__$a,
    __vue_script__$a,
    __vue_scope_id__$a,
    __vue_is_functional_template__$a,
    __vue_module_identifier__$a,
    false,
    undefined,
    undefined,
    undefined
  );

var script$b = {
  name: 'VerificationItem',
  components: {
    ShadowItem: __vue_component__$3,
    VerificationItemRevoked: __vue_component__$6,
    VerificationItemRevokedUnverified: __vue_component__$7,
    VerificationItemNotFound: __vue_component__$5,
    VerificationItemUnverifiedIssuer: __vue_component__$8,
    VerificationItemVerified: __vue_component__$9,
    VerificationItemTechnicalProblem: __vue_component__$a
  },
  props: {
    verificationItem: {
      type: Object,
      required: true
    }
  },
  computed: {
    verificationItemType: function verificationItemType() {
      if (this.verificationItem.hashed === undefined || this.verificationItem.hashed === false) {
        return 'ShadowItem';
      }

      switch (this.verificationItem.type) {
        case VERIFICATION_TYPES.V_REVOKED:
          if (this.verificationItem.issuerVerified) {
            return 'VerificationItemRevoked';
          }

          return 'VerificationItemRevokedUnverified';

        case VERIFICATION_TYPES.V_NOT_FOUND:
          return 'VerificationItemNotFound';

        case VERIFICATION_TYPES.V_SELF_DECLARED:
          return 'VerificationItemUnverifiedIssuer';

        case VERIFICATION_TYPES.V_VERIFIED:
          return 'VerificationItemVerified';
      }

      return 'VerificationItemTechnicalProblem';
    }
  }
};

/* script */
const __vue_script__$b = script$b;

/* template */
var __vue_render__$b = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',{staticClass:"item-container"},[_c(_vm.verificationItemType,{tag:"component",attrs:{"verificationItem":_vm.verificationItem}})],1)};
var __vue_staticRenderFns__$b = [];

  /* style */
  const __vue_inject_styles__$b = undefined;
  /* scoped */
  const __vue_scope_id__$b = undefined;
  /* module identifier */
  const __vue_module_identifier__$b = undefined;
  /* functional template */
  const __vue_is_functional_template__$b = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$b = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$b, staticRenderFns: __vue_staticRenderFns__$b },
    __vue_inject_styles__$b,
    __vue_script__$b,
    __vue_scope_id__$b,
    __vue_is_functional_template__$b,
    __vue_module_identifier__$b,
    false,
    undefined,
    undefined,
    undefined
  );

var demoDocuments = {
  notFound: {
    name: 'Demo_Document_NotFound.pdf',
    hash: '0x8db3dfe7de59e35f5f8be5fde6da543b57ccc017388def7c0a1db7af24db4abf',
    issuerAddress: null,
    issuerName: null,
    issuerImg: null,
    issuerVerified: false,
    revoked: false,
    expiry: null,
    loaded: true
  },
  technicalProblem: {
    name: 'Demo_Document_TechnicalProblem.pdf',
    hash: '0x8db3dfe7de59e35f5f8be5fde6da543b57ccc017388def7c0a1db7af24db4abf',
    issuerAddress: null,
    issuerName: null,
    issuerImg: null,
    issuerVerified: false,
    revoked: false,
    expiry: null,
    loaded: true,
    offchainError: true
  },
  verifiedProcessing: {
    hashed: true,
    name: 'Demo_Document_Verified_Processing.pdf',
    hash: '0x33e63485a8594ee7d1cfbb418a6f5acf7532faca38aa8a36b23eec8f6a53d179',
    onBlockchain: false,
    issuerAddress: undefined,
    issuerName: 'Demo University',
    issuerImg: null,
    issuerVerified: true,
    revoked: false,
    expiry: undefined,
    status: 'registering',
    loaded: true
  },
  verified: {
    hashed: true,
    name: 'Demo_Document_Verified.pdf',
    hash: '0x33e63485a8594ee7d1cfbb418a6f5acf7532faca38aa8a36b23eec8f6a53d179',
    onBlockchain: true,
    issuerAddress: '0xD0f6C73Bf87d1A00797A8A1DF2dF0Dad89D2411f',
    issuerName: 'Demo University',
    issuerImg: null,
    issuerVerified: true,
    revoked: false,
    expiry: null,
    registrationEvent: {
      address: '0x5ee4ec3cbee909050e68c7ff7a8b422cfbd72244',
      blockHash: '0xa95f5fce5e6ebfcbdb8bbd932e412fd376dc8b7189b8d8572fe9d4d8994961de',
      blockNumber: 7937331,
      transactionHash: '0x9b7e8f75ae271d8d659eb7bbd6d090fad3c784f862a5a83368fbc970bfa0a215 ',
      event: 'FileRegisteredEvent',
      signature: '0x98b03391b6b42a1d067881e3d2a22b2091e0412a0e2c40cf687d1c036beb6e11'
    },
    registrationBlock: {
      hash: '0x9b7e8f75ae271d8d659eb7bbd6d090fad3c784f862a5a83368fbc970bfa0a215',
      timestamp: 1560246087
    },
    loaded: true
  },
  verifiedSelfDeclared: {
    hashed: true,
    name: 'Demo_Document_Verified_Self_Declared.pdf',
    hash: '0x33e63485a8594ee7d1cfbb418a6f5acf7532faca38aa8a36b23eec8f6a53d179',
    onBlockchain: true,
    issuerAddress: '0xD0f6C73Bf87d1A00797A8A1DF2dF0Dad89D2411f',
    issuerName: 'Demo University',
    issuerImg: null,
    issuerVerified: false,
    revoked: false,
    expiry: null,
    registrationEvent: {
      address: '0x5ee4ec3cbee909050e68c7ff7a8b422cfbd72244',
      blockHash: '0xa95f5fce5e6ebfcbdb8bbd932e412fd376dc8b7189b8d8572fe9d4d8994961de',
      blockNumber: 7937331,
      transactionHash: '0x9b7e8f75ae271d8d659eb7bbd6d090fad3c784f862a5a83368fbc970bfa0a215 ',
      event: 'FileRegisteredEvent',
      signature: '0x98b03391b6b42a1d067881e3d2a22b2091e0412a0e2c40cf687d1c036beb6e11'
    },
    registrationBlock: {
      hash: '0x9b7e8f75ae271d8d659eb7bbd6d090fad3c784f862a5a83368fbc970bfa0a215',
      timestamp: 1560246087
    },
    loaded: true
  },
  revokedVerified: {
    hashed: true,
    name: 'Demo_Document_RevokedVerified.pdf',
    hash: '0x33e63485a8594ee7d1cfbb418a6f5acf7532faca38aa8a36b23eec8f6a53d179',
    onBlockchain: true,
    issuerAddress: '0xD0f6C73Bf87d1A00797A8A1DF2dF0Dad89D2411f',
    issuerName: 'Demo University',
    issuerImg: null,
    issuerVerified: true,
    revoked: true,
    expiry: null,
    registrationEvent: {
      address: '0x5ee4ec3cbee909050e68c7ff7a8b422cfbd72244',
      blockHash: '0xa95f5fce5e6ebfcbdb8bbd932e412fd376dc8b7189b8d8572fe9d4d8994961de',
      blockNumber: 7937331,
      transactionHash: '0x9b7e8f75ae271d8d659eb7bbd6d090fad3c784f862a5a83368fbc970bfa0a215',
      event: 'FileRegisteredEvent',
      signature: '0x98b03391b6b42a1d067881e3d2a22b2091e0412a0e2c40cf687d1c036beb6e11'
    },
    registrationBlock: {
      hash: '0x9b7e8f75ae271d8d659eb7bbd6d090fad3c784f862a5a83368fbc970bfa0a215',
      timestamp: 1560246087
    },
    revocationEvent: {
      address: '0x5ee4ec3cbee909050e68c7ff7a8b422cfbd72244',
      blockHash: '0xa95f5fce5e6ebfcbdb8bbd932e412fd376dc8b7189b8d8572fe9d4d8994961de',
      blockNumber: 7937331,
      transactionHash: '0x9b7e8f75ae271d8d659eb7bbd6d090fad3c784f862a5a83368fbc970bfa0a215',
      event: 'FileRegisteredEvent',
      signature: '0x98b03391b6b42a1d067881e3d2a22b2091e0412a0e2c40cf687d1c036beb6e11'
    },
    revocationBlock: {
      hash: '0x9b7e8f75ae271d8d659eb7bbd6d090fad3c784f862a5a83368fbc970bfa0a215',
      timestamp: 1560346087
    },
    loaded: true
  }
};

var script$c = {
  name: 'CertifactionVerification',
  mixins: [i18nWrapperMixin],
  components: {
    VerificationDemo: __vue_component__$1,
    VerificationDropBox: __vue_component__$2,
    VerificationItem: __vue_component__$b
  },
  props: {
    demo: {
      type: Boolean,
      required: false,
      default: false
    },
    pdfWasmUrl: {
      type: String,
      required: true
    },
    providerUrl: {
      type: String,
      required: false
    },
    legacyContractAddress: {
      type: String,
      required: false
    },
    legacyContractFallbackAddresses: {
      type: Array,
      required: false
    },
    claimContractAddress: {
      type: String,
      required: false
    },
    acceptedIssuerKey: {
      type: String,
      required: false
    },
    certifactionApiUrl: {
      type: String,
      required: false
    },
    offchainVerifier: {
      type: Object,
      required: false,
      validator: function validator(value) {
        Interface.ensureImplements(value, VerifierInterface);
        return true;
      }
    }
  },
  data: function data() {
    return {
      certifactionEthVerifier: new CertifactionEthVerifier(this.providerUrl, this.legacyContractAddress, this.legacyContractFallbackAddresses, this.claimContractAddress, this.acceptedIssuerKey, this.certifactionApiUrl),
      pdfService: new PdfService(this.pdfWasmUrl),
      verificationItems: [],
      draggingDemoDoc: undefined
    };
  },
  computed: {
    filteredVerificationItems: function filteredVerificationItems() {
      return this.verificationItems.map(function (item) {
        if (item.hash === undefined && !item.error) {
          return {
            hashed: false
          };
        }

        return _objectSpread2({
          hashed: true,
          type: mapVerificationItemType(item)
        }, item);
      });
    }
  },
  methods: {
    verify: function verify(files) {
      var _this = this;

      return _asyncToGenerator(regeneratorRuntime.mark(function _callee() {
        var _iterator, _step, file, _iterator2, _step2, _step2$value, key, item;

        return regeneratorRuntime.wrap(function _callee$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                _this.verificationItems = [];
                _context.prev = 1;
                _iterator = _createForOfIteratorHelper(files);

                try {
                  for (_iterator.s(); !(_step = _iterator.n()).done;) {
                    file = _step.value;

                    _this.verificationItems.push({
                      file: file,
                      name: file.name
                    });
                  }
                } catch (err) {
                  _iterator.e(err);
                } finally {
                  _iterator.f();
                }

                _iterator2 = _createForOfIteratorHelper(_this.verificationItems.entries());

                try {
                  for (_iterator2.s(); !(_step2 = _iterator2.n()).done;) {
                    _step2$value = _slicedToArray(_step2.value, 2), key = _step2$value[0], item = _step2$value[1];

                    _this.verifyItem(item, key);
                  }
                } catch (err) {
                  _iterator2.e(err);
                } finally {
                  _iterator2.f();
                }

                _context.next = 8;
                return _this.$nextTick();

              case 8:
                VueScrollTo.scrollTo(_this.$refs.results, 400);
                _context.next = 14;
                break;

              case 11:
                _context.prev = 11;
                _context.t0 = _context["catch"](1);
                console.log(_context.t0);

              case 14:
              case "end":
                return _context.stop();
            }
          }
        }, _callee, null, [[1, 11]]);
      }))();
    },
    verifyItem: function verifyItem(item, key) {
      var _this2 = this;

      return _asyncToGenerator(regeneratorRuntime.mark(function _callee2() {
        var pdfBytes, _yield$Promise$all, _yield$Promise$all2, fileHash, encryptionKeys, decryptionKey, verification;

        return regeneratorRuntime.wrap(function _callee2$(_context2) {
          while (1) {
            switch (_context2.prev = _context2.next) {
              case 0:
                _context2.next = 2;
                return _this2.pdfService.readPdfBytes(item.file);

              case 2:
                pdfBytes = _context2.sent;
                _context2.next = 5;
                return Promise.all([hashingService.hashFile(pdfBytes), _this2.pdfService.extractEncryptionKeys(pdfBytes)]);

              case 5:
                _yield$Promise$all = _context2.sent;
                _yield$Promise$all2 = _slicedToArray(_yield$Promise$all, 2);
                fileHash = _yield$Promise$all2[0];
                encryptionKeys = _yield$Promise$all2[1];
                decryptionKey = encryptionKeys !== null ? encryptionKeys.privateKey : null;
                _context2.next = 12;
                return _this2.certifactionEthVerifier.verify(fileHash, decryptionKey);

              case 12:
                verification = _context2.sent;
                Vue.set(_this2.verificationItems, key, _objectSpread2(_objectSpread2({}, item), verification));

                if (!_this2.offchainVerifier) {
                  _context2.next = 18;
                  break;
                }

                _context2.next = 17;
                return _this2.offchainVerification(verification, decryptionKey);

              case 17:
                verification = _context2.sent;

              case 18:
                verification.loaded = true;
                Vue.set(_this2.verificationItems, key, _objectSpread2(_objectSpread2({}, item), verification));

              case 20:
              case "end":
                return _context2.stop();
            }
          }
        }, _callee2);
      }))();
    },
    offchainVerification: function offchainVerification(verification, decryptionKey) {
      var _this3 = this;

      return _asyncToGenerator(regeneratorRuntime.mark(function _callee3() {
        var offchainVerification, claimVerification, identityVerifier;
        return regeneratorRuntime.wrap(function _callee3$(_context3) {
          while (1) {
            switch (_context3.prev = _context3.next) {
              case 0:
                _context3.prev = 0;
                _context3.next = 3;
                return _this3.offchainVerifier.verify(verification.hash);

              case 3:
                offchainVerification = _context3.sent;

                if (!offchainVerification) {
                  _context3.next = 20;
                  break;
                }

                if (!(offchainVerification.encrypted && offchainVerification.claims && offchainVerification.claims.length > 0)) {
                  _context3.next = 16;
                  break;
                }

                _context3.next = 8;
                return _this3.certifactionEthVerifier.certifactionClaimVerifier.resolveAndVerifyClaims(offchainVerification.claims, decryptionKey);

              case 8:
                claimVerification = _context3.sent;
                offchainVerification.claims = claimVerification.claims;

                if (!offchainVerification.revoked) {
                  offchainVerification.revoked = claimVerification.revoked;
                }

                if (!offchainVerification.issuerVerified && typeof claimVerification.issuerVerified === 'boolean') {
                  offchainVerification.issuerVerified = claimVerification.issuerVerified;
                }

                if (!offchainVerification.issuerAddress && claimVerification.issuerAddress) {
                  offchainVerification.issuerAddress = claimVerification.issuerAddress;
                }

                if (!offchainVerification.issuerName && claimVerification.issuerName) {
                  offchainVerification.issuerName = claimVerification.issuerName;
                }

                if (!offchainVerification.issuerVerifiedBy && claimVerification.issuerVerifiedBy) {
                  offchainVerification.issuerVerifiedBy = claimVerification.issuerVerifiedBy;
                }

                if (!offchainVerification.issuerVerifiedImg && claimVerification.issuerVerifiedImg) {
                  offchainVerification.issuerVerifiedImg = claimVerification.issuerVerifiedImg;
                }

              case 16:
                identityVerifier = {};

                if (offchainVerification.issuerVerifiedBy) {
                  identityVerifier.name = offchainVerification.issuerVerifiedBy;
                }

                if (offchainVerification.issuerVerifiedImg) {
                  identityVerifier.image = offchainVerification.issuerVerifiedImg;
                }

                if (!verification.events && offchainVerification.status === 'registering') {
                  verification = _objectSpread2(_objectSpread2(_objectSpread2({}, verification), offchainVerification), {}, {
                    events: [{
                      scope: 'register',
                      issuer: offchainVerification.issuerName,
                      identityVerifier: Object.keys(identityVerifier).length > 0 ? identityVerifier : null
                    }]
                  });
                } else if (['registered', 'registering', 'revoking', 'revoked'].indexOf(offchainVerification.status) >= 0) {
                  if (!verification.issuerName && offchainVerification.issuerName) {
                    verification.issuerName = offchainVerification.issuerName;
                  }

                  if (!verification.issuerVerified && typeof offchainVerification.issuerVerified === 'boolean') {
                    verification.issuerVerified = offchainVerification.issuerVerified;
                  }

                  if (!verification.issuerVerifiedBy && offchainVerification.issuerVerifiedBy) {
                    verification.issuerVerifiedBy = offchainVerification.issuerVerifiedBy;
                  }

                  if (!verification.issuerVerifiedImg && offchainVerification.issuerVerifiedImg) {
                    verification.issuerVerifiedImg = offchainVerification.issuerVerifiedImg;
                  }

                  if (verification.events && verification.events.length > 0) {
                    verification.events = verification.events.map(function (event) {
                      var newEvent = _objectSpread2({}, event);

                      var identityVerifier = _objectSpread2({}, event.identityVerifier);

                      if (!event.issuer && offchainVerification.issuerName) {
                        newEvent.issuer = offchainVerification.issuerName;
                      }

                      if (!identityVerifier.name && offchainVerification.issuerVerifiedBy) {
                        identityVerifier.name = offchainVerification.issuerVerifiedBy;
                      }

                      if (!identityVerifier.image && offchainVerification.issuerVerifiedImg) {
                        identityVerifier.image = offchainVerification.issuerVerifiedImg;
                      }

                      if (Object.keys(identityVerifier).length > 0) {
                        newEvent.identityVerifier = identityVerifier;
                      }

                      return newEvent;
                    });
                  } else {
                    verification.events = [{
                      scope: 'register',
                      issuer: offchainVerification.issuerName,
                      identityVerifier: Object.keys(identityVerifier).length > 0 ? identityVerifier : null
                    }];
                  }
                }

              case 20:
                _context3.next = 26;
                break;

              case 22:
                _context3.prev = 22;
                _context3.t0 = _context3["catch"](0);
                console.log("Error while verifying by offchain verification: ".concat(_context3.t0.name, " - ").concat(_context3.t0.message));
                verification.offchainError = true;

              case 26:
                console.log("Verification result for file ".concat(verification.hash, ":"), verification);
                return _context3.abrupt("return", verification);

              case 28:
              case "end":
                return _context3.stop();
            }
          }
        }, _callee3, null, [[0, 22]]);
      }))();
    },
    onDraggingDemoDoc: function onDraggingDemoDoc(demoDoc) {
      this.draggingDemoDoc = demoDoc;
    },
    drop: function drop() {
      if (this.draggingDemoDoc) {
        this.verifyDemo(this.draggingDemoDoc);
      }
    },
    verifyDemo: function verifyDemo(type) {
      var _this4 = this;

      return _asyncToGenerator(regeneratorRuntime.mark(function _callee4() {
        return regeneratorRuntime.wrap(function _callee4$(_context4) {
          while (1) {
            switch (_context4.prev = _context4.next) {
              case 0:
                if (!demoDocuments[type]) {
                  _context4.next = 5;
                  break;
                }

                _this4.verificationItems = [demoDocuments[type]];
                _context4.next = 4;
                return _this4.$nextTick();

              case 4:
                VueScrollTo.scrollTo(_this4.$refs.results, 400);

              case 5:
              case "end":
                return _context4.stop();
            }
          }
        }, _callee4);
      }))();
    }
  }
};

const img = "data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='632.421' height='103.961' viewBox='0 0 632.421 103.961' fill='%23203346'%3e%3cpath d='M0 21.02L21.02.167 42.04 21.02 21.02 41.87zm83.226 0L104.245.167l21.02 20.852-21.02 20.852z'/%3e%3cpath d='M20.805 41.66l21.02-20.852 21.02 20.852-21.02 20.852z'/%3e%3cpath d='M62.42 41.66l21.02-20.852 21.02 20.852L83.44 62.5zM0 62.3l21.02-20.85L42.038 62.3 21.02 83.153z'/%3e%3cpath d='M20.805 82.943h42.038l-21.02 20.852z'/%3e%3cpath d='M62.632 82.733l21.02 20.852z'/%3e%3cpath d='M20.805 82.943l21.02-20.852 21.02 20.852z' opacity='.5'/%3e%3cpath d='M62.42 82.943L83.44 62.09l21.02 20.852z' opacity='.5'/%3e%3cpath d='M62.42 82.943h42.038l-21.02 20.852z'/%3e%3cpath d='M83.226 62.3l21.02-20.852 21.02 20.852-21.02 20.852zM212.98 76.812c-1.314 4.777-4.3 8.918-8.435 11.66a26 26 0 0 1-14.494 3.937 27.67 27.67 0 0 1-13.839-3.33 22.25 22.25 0 0 1-9.048-9.545 32.22 32.22 0 0 1-3.154-14.747 32.22 32.22 0 0 1 3.153-14.745c1.98-4.012 5.117-7.338 9.008-9.545a27.26 27.26 0 0 1 13.716-3.332c4.992-.158 9.933 1.05 14.3 3.493 3.903 2.327 6.783 6.04 8.066 10.4l-10.235 4.306q-1.3-4.793-4.094-6.906a12.18 12.18 0 0 0-7.534-2.112q-6.88 0-10.766 4.793-3.887 4.793-3.893 13.648 0 8.855 3.767 13.648 3.767 4.793 10.644 4.794 9.907 0 12.447-9.5zm46.76-5.7a28.6 28.6 0 0 1-.328 4.387h-28.988q1.718 8.613 10.236 8.613a11.66 11.66 0 0 0 5.814-1.3 6.95 6.95 0 0 0 3.194-3.737l9.172 3.33c-1.248 3.18-3.584 5.814-6.592 7.433a23.73 23.73 0 0 1-11.587 2.557q-10.154 0-15.723-5.567-5.57-5.567-5.57-15.55 0-9.992 5.4-15.557 5.4-5.565 15.233-5.568 9.5 0 14.617 5.443 5.117 5.443 5.12 15.516zm-19.817-12.75c-2.4-.123-4.745.727-6.5 2.356-1.773 1.923-2.853 4.382-3.07 6.988h19.08a11.72 11.72 0 0 0-3.112-6.944 8.76 8.76 0 0 0-6.387-2.4zm52.4-8.206c1.526-.084 3.048.224 4.422.893l-1.392 9.747c-1.568-.9-3.358-1.314-5.16-1.218a9.49 9.49 0 0 0-6.92 2.884q-2.907 2.884-2.907 8.083v21.043h-11.22v-40.62h9.745l.74 7.96q3.354-8.773 12.7-8.773zm37.915 38.915a14.81 14.81 0 0 1-4.954 2.437c-2.034.6-4.144.902-6.265.893q-13.674 0-13.674-12.267v-20.88H297.9v-8.287h7.454v-9.342l11.22-3.087v12.43h13.266v8.287h-13.267v19.1q0 5.605 5.65 5.605c2.306.033 4.546-.775 6.3-2.273zm12.693-43.958q-6.96 0-6.96-5.93 0-6.012 6.96-6.012 6.96 0 6.96 6.012 0 5.93-6.96 5.93zm5.57 46.47H337.3v-40.62h11.22zm25.55-40.62H387v8.287h-12.45v32.333h-11.218V59.265h-7.124v-8.287h7.124v-4.874q0-6.662 4.176-10.2 4.176-3.538 11.3-3.534c1.668-.016 3.332.175 4.954.568a10.1 10.1 0 0 1 3.562 1.544l-1.556 7.393a8.42 8.42 0 0 0-4.668-1.218q-7.044 0-7.044 6.256zm55.52 33.877a9.79 9.79 0 0 0 2.784-.325l-.82 6.746a11.82 11.82 0 0 1-5.326 1.136q-7.858 0-9.414-6.094a11.16 11.16 0 0 1-5.566 4.553c-2.847 1.1-5.88 1.614-8.928 1.544q-5.978 0-9.334-2.68a9.3 9.3 0 0 1-3.357-7.718q0-9.912 15.97-12.836l9.827-1.868v-1.954c.1-1.897-.564-3.754-1.842-5.16a6.78 6.78 0 0 0-5.118-1.91c-2.165-.095-4.307.472-6.142 1.625-1.715 1.287-2.885 3.172-3.276 5.28l-8.93-3.737a13.47 13.47 0 0 1 5.9-8.287q4.586-3.006 11.956-3.006 8.762 0 13.676 3.778 4.914 3.778 4.913 11.17v16.656c-.078.852.188 1.7.737 2.356.637.537 1.462.8 2.292.73zm-23.748 0a12.83 12.83 0 0 0 6.592-1.747 5.32 5.32 0 0 0 2.99-4.752v-4.224l-8.762 1.95a10.35 10.35 0 0 0-4.135 1.747 3.7 3.7 0 0 0-1.35 3.047c-.074 1.126.38 2.222 1.228 2.965a5.21 5.21 0 0 0 3.44 1.015zm51.918-34.7q8.107 0 12.6 3.25c2.97 2.12 5.135 5.184 6.142 8.692l-10.48 3.737q-1.474-7.393-7.943-7.393a8.86 8.86 0 0 0-7.411 3.29q-2.58 3.3-2.577 9.623.002 6.333 2.62 9.545a8.9 8.9 0 0 0 7.288 3.22q7.206 0 8.517-7.23l10.154 3.25a14.6 14.6 0 0 1-6.106 8.938q-4.8 3.33-12.407 3.33-10.154 0-15.723-5.567-5.57-5.567-5.57-15.554 0-9.992 5.527-15.557 5.527-5.565 15.357-5.563zm55.93 38.915a14.81 14.81 0 0 1-4.949 2.446 21.81 21.81 0 0 1-6.264.893q-13.676 0-13.676-12.267v-20.88h-7.46V50.98h7.452v-9.34l11.22-3.087v12.43h13.266v8.287h-13.264v19.1q0 5.605 5.65 5.605c2.306.033 4.546-.775 6.3-2.273zm12.693-43.954q-6.96 0-6.96-5.928 0-6.012 6.96-6.012 6.96 0 6.96 6.012 0 5.93-6.963 5.93zm5.568 46.47h-11.22V50.96h11.22zm30.708-41.42q9.907 0 15.437 5.605 5.53 5.605 5.528 15.517 0 9.912-5.528 15.517-5.528 5.605-15.437 5.605-9.907 0-15.436-5.605-5.53-5.605-5.523-15.517 0-9.912 5.528-15.517 5.528-5.605 15.43-5.605zm0 8.287a8.63 8.63 0 0 0-7.247 3.208q-2.5 3.208-2.5 9.623 0 6.415 2.5 9.623a8.64 8.64 0 0 0 7.245 3.209 8.63 8.63 0 0 0 7.248-3.209q2.5-3.2 2.5-9.623 0-6.414-2.5-9.623a8.64 8.64 0 0 0-7.246-3.204zm55.032-8.287q6.633 0 10.686 3.818 4.053 3.818 4.054 10.964v26.65h-11.22v-23.4q0-9.26-7.288-9.26a9.05 9.05 0 0 0-6.674 2.762q-2.743 2.762-2.743 8.45V91.59h-11.22V50.97h10.072l.328 7.23c1.24-2.523 3.2-4.617 5.65-6.012a16.72 16.72 0 0 1 8.353-2.031zM62.625 82.736l20.975 20.8H41.65z'/%3e%3c/svg%3e";

/* script */
const __vue_script__$c = script$c;
var __vue_render__$c = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',{staticClass:"certifaction-verification"},[(_vm.demo !== false)?_c('VerificationDemo',{on:{"verifyDemo":_vm.verifyDemo,"draggingDemoDoc":_vm.onDraggingDemoDoc}}):_vm._e(),_vm._v(" "),_c('VerificationDropBox',{on:{"filesDropped":_vm.verify,"drop":_vm.drop}}),_vm._v(" "),(_vm.filteredVerificationItems.length)?_c('div',{ref:"results",staticClass:"verification-item-list"},_vm._l((_vm.filteredVerificationItems),function(verificationItem){return _c('VerificationItem',{key:verificationItem.hash,attrs:{"verificationItem":verificationItem}})}),1):_vm._e(),_vm._v(" "),_c('div',{staticClass:"powered-by"},[_c('span',{staticClass:"label"},[_vm._v(_vm._s(_vm._$t('verification.poweredBy.label')))]),_vm._v(" "),_vm._m(0)])],1)};
var __vue_staticRenderFns__$c = [function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('a',{attrs:{"href":"https://certifaction.io","target":"_blank"}},[_c('img',{attrs:{"src":img,"alt":"Certifaction"}})])}];

  /* style */
  const __vue_inject_styles__$c = undefined;
  /* scoped */
  const __vue_scope_id__$c = undefined;
  /* module identifier */
  const __vue_module_identifier__$c = undefined;
  /* functional template */
  const __vue_is_functional_template__$c = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$c = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$c, staticRenderFns: __vue_staticRenderFns__$c },
    __vue_inject_styles__$c,
    __vue_script__$c,
    __vue_scope_id__$c,
    __vue_is_functional_template__$c,
    __vue_module_identifier__$c,
    false,
    undefined,
    undefined,
    undefined
  );

export { __vue_component__$c as CertifactionVerification };
//# sourceMappingURL=verification-vue-component.esm.js.map
